@@ -1,13 +1,13 @@
 from .paystack_config import *
 from .errors import *
 from .customers import Customer
+from .plans import Plan
+from .filters import Filter
 import requests
 import json
 import jsonpickle
 import validators
 import math
-from .plans import Plan
-
 
 class Manager():
     '''
@@ -229,7 +229,7 @@ class PaymentManager(Manager):
         endpoint += reference
         url = self.PAYSTACK_URL + self.__endpoint + endpoint
 
-        headers, data = self.build_request_args()
+        headers,_ = self.build_request_args()
         response = requests.get(url, headers = headers)
         content = response.content
         content = self.parse_response_content(content)
@@ -332,7 +332,7 @@ class CustomersManager(Manager):
         '''
         Method which returns all registered customers
         '''
-        headers, data = self.build_request_args()
+        headers,_ = self.build_request_args()
 
         response  = requests.get(self.PAYSTACK_URL + self.__endpoint, headers = headers)
 
@@ -357,7 +357,7 @@ class CustomersManager(Manager):
         id : Customer id
 
         '''
-        headers, data = self.build_request_args()
+        headers,_ = self.build_request_args()
         url = "%s%s/%s" % (self.PAYSTACK_URL, self.__endpoint, id)
         response = requests.get(url, headers = headers)
 
@@ -494,7 +494,7 @@ class PlanManager(Manager):
             raise APIConnectionFailedError(message)
 
     def get_plans(self):
-        headers, data = self.build_request_args()
+        headers,_ = self.build_request_args()
         response = requests.get(self.PAYSTACK_URL + self.__endpoint, headers = headers)
 
         content = response.content
@@ -510,7 +510,7 @@ class PlanManager(Manager):
 
     #Implement as class method to return a Plan object
     def get_plan(self, id):
-        headers, data = self.build_request_args()
+        headers,_ = self.build_request_args()
 
         url = "%s%s/%s" % (self.PAYSTACK_URL,self.__endpoint, id)
         response = requests.get(url, headers = headers)
@@ -566,7 +566,10 @@ class TransactionsManager(Manager):
             raise APIConnectionFailedError(message)       
         
     def get_total_transactions(self):
-        headers, data = self.build_request_args(params)
+        '''
+        Get total amount gotten from transactions
+        '''
+        headers,_ = self.build_request_args()
         url = self.PAYSTACK_URL + self.__endpoint
         url += '/totals'
         response = requests.get(url, headers = headers)
@@ -585,7 +588,7 @@ class TransactionsManager(Manager):
         '''
         Gets all transactions
         '''
-        headers, data = self.build_request_args(params)
+        headers,_ = self.build_request_args()
         response = requests.get(self.PAYSTACK_URL + self.__endpoint, headers = headers)
 
         content = response.content
@@ -617,3 +620,13 @@ class TransactionsManager(Manager):
             return content['data']
         else:
             raise APIConnectionFailedError(message)
+
+    
+    def filter_transactions(self, amount_range : range, transactions):
+        
+        results = []
+        for transaction in transactions:
+            if Filter.filter_amount(amount_range, transaction):
+                results.append(transaction)
+
+        return results
\ No newline at end of file
